@@ -12,6 +12,7 @@ type 'a gen = 'a t
 module type S = Gen_intf.S
 
 (*$inject
+  [@@@ocaml.warning "-26"]
 
   let pint i = string_of_int i
   let pilist l =
@@ -334,13 +335,8 @@ let flat_map f next_elem =
     | Stop -> None
   and get_next_gen() = match next_elem() with
     | None -> state:=Stop; None
-    | Some x ->
-        begin try state := Run (f x)
-          with e ->
-            state := Stop;
-            raise e
-        end;
-        next()
+    | Some x -> state := Run (f x); next()
+    | exception e -> state := Stop; raise e
   in
   next
 
